@@ -448,5 +448,7 @@ class BatchTrialTest(TestCase):
         self.assertEqual(batch_trial._status_quo_weight_override, np.sqrt(2))
 
     def testRepr(self):
-        repr_ = "BatchTrial(experiment_name='test', index=0, status=TrialStatus.CANDIDATE)"  # noqa
-        self.assertEqual(str(self.batch), repr_)
+        self.assertEqual(
+            str(self.batch),
+            "BatchTrial(experiment_name='test', index=0, status=TrialStatus.CANDIDATE)",
+        )
