@@ -64,11 +64,18 @@ try:  # We don't require SQLAlchemy by default.
     from ax.storage.sqa_store.structs import DBSettings
     from ax.service.utils.storage import (
         load_experiment_and_generation_strategy,
-        save_experiment_and_generation_strategy,
         save_experiment,
+        save_generation_strategy,
+        save_new_trial,
+        save_updated_trial,
     )
+
+    retry_exception_type_tuple = (OperationalError,)
 except ModuleNotFoundError:  # pragma: no cover
     DBSettings = None
+    # Return a list of suppressable exceptions not including unimportable ones.
+    # pyre-fixme[9]: declared as `Tuple[...[OperationalError]]` but used as `Tuple[]`.
+    retry_exception_type_tuple = ()
 
 
 class AxClient:
@@ -265,7 +272,10 @@ class AxClient:
         self._set_generation_strategy(
             choose_generation_strategy_kwargs=choose_generation_strategy_kwargs
         )
-        self._save_experiment_and_maybe_generation_strategy_to_db_if_possible(
+        self._save_experiment_to_db_if_possible(
+            suppress_all_errors=self._suppress_storage_errors
+        )
+        self._save_generation_strategy_to_db_if_possible(
             suppress_all_errors=self._suppress_storage_errors
         )
 
@@ -284,7 +294,10 @@ class AxClient:
             f"{_round_floats_for_logging(item=not_none(trial.arm).parameters)}."
         )
         trial.mark_running(no_runner_required=True)
-        self._save_experiment_and_maybe_generation_strategy_to_db_if_possible(
+        self._save_new_trial_to_db_if_possible(
+            trial=trial, suppress_all_errors=self._suppress_storage_errors
+        )
+        self._save_generation_strategy_to_db_if_possible(
             suppress_all_errors=self._suppress_storage_errors
         )
         return not_none(trial.arm).parameters, trial.index
@@ -332,9 +345,8 @@ class AxClient:
             f"Completed trial {trial_index} with data: "
             f"{_round_floats_for_logging(item=data_for_logging)}."
         )
-        self._save_experiment_and_maybe_generation_strategy_to_db_if_possible(
-            save_generation_strategy=False,  # No changes were made to gen. strategy.
-            suppress_all_errors=self._suppress_storage_errors,
+        self._save_updated_trial_to_db_if_possible(
+            trial=trial, suppress_all_errors=self._suppress_storage_errors
         )
 
     def update_trial_data(
@@ -382,9 +394,8 @@ class AxClient:
             f"Added data: {_round_floats_for_logging(item=data_for_logging)} "
             f"to trial {trial.index}."
         )
-        self._save_experiment_and_maybe_generation_strategy_to_db_if_possible(
-            save_generation_strategy=False,  # No changes were made to gen. strategy.
-            suppress_all_errors=self._suppress_storage_errors,
+        self._save_experiment_to_db_if_possible(
+            suppress_all_errors=self._suppress_storage_errors
         )
 
     def log_trial_failure(
@@ -401,9 +412,8 @@ class AxClient:
         logger.info(f"Registered failure of trial {trial_index}.")
         if metadata is not None:
             trial._run_metadata = metadata
-        self._save_experiment_and_maybe_generation_strategy_to_db_if_possible(
-            save_generation_strategy=False,  # No changes were made to gen. strategy.
-            suppress_all_errors=self._suppress_storage_errors,
+        self._save_experiment_to_db_if_possible(
+            suppress_all_errors=self._suppress_storage_errors
         )
 
     def attach_trial(
@@ -424,9 +434,8 @@ class AxClient:
             "Attached custom parameterization "
             f"{_round_floats_for_logging(item=parameters)} as trial {trial.index}."
         )
-        self._save_experiment_and_maybe_generation_strategy_to_db_if_possible(
-            save_generation_strategy=False,  # No changes were made to gen. strategy.
-            suppress_all_errors=self._suppress_storage_errors,
+        self._save_new_trial_to_db_if_possible(
+            trial=trial, suppress_all_errors=self._suppress_storage_errors
         )
         return not_none(trial.arm).parameters, trial.index
 
@@ -823,10 +832,10 @@ class AxClient:
     @retry_on_exception(
         retries=3,
         default_return_on_suppression=False,
-        exception_type=(OperationalError,),
+        exception_type=retry_exception_type_tuple,
     )
-    def _save_experiment_and_maybe_generation_strategy_to_db_if_possible(
-        self, save_generation_strategy: bool = True, suppress_all_errors: bool = False
+    def _save_experiment_to_db_if_possible(
+        self, suppress_all_errors: bool = False
     ) -> bool:
         """Saves attached experiment and generation strategy if DB settings are
         set on this AxClient instance.
@@ -835,16 +844,71 @@ class AxClient:
             bool: Whether the experiment was saved.
         """
         if self.db_settings is not None:
-            if save_generation_strategy:
-                save_experiment_and_generation_strategy(
-                    experiment=self.experiment,
-                    generation_strategy=self.generation_strategy,
-                    db_settings=self.db_settings,
-                )
-            else:
-                save_experiment(
-                    experiment=self.experiment, db_settings=self.db_settings
-                )
+            save_experiment(experiment=self.experiment, db_settings=self.db_settings)
+            return True
+        return False
+
+    @retry_on_exception(
+        retries=3,
+        default_return_on_suppression=False,
+        exception_type=retry_exception_type_tuple,
+    )
+    def _save_new_trial_to_db_if_possible(
+        self, trial: BaseTrial, suppress_all_errors: bool = False
+    ) -> bool:
+        """Saves given trial and generation strategy if DB settings are
+        set on this AxClient instance.
+
+        Returns:
+            bool: Whether the experiment was saved.
+        """
+        if self.db_settings is not None:
+            save_new_trial(
+                experiment=self.experiment, trial=trial, db_settings=self.db_settings
+            )
+            return True
+        return False
+
+    @retry_on_exception(
+        retries=3,
+        default_return_on_suppression=False,
+        exception_type=retry_exception_type_tuple,
+    )
+    def _save_updated_trial_to_db_if_possible(
+        self, trial: BaseTrial, suppress_all_errors: bool = False
+    ) -> bool:
+        """Saves attached experiment and generation strategy if DB settings are
+        set on this AxClient instance.
+
+        Returns:
+            bool: Whether the experiment was saved.
+        """
+        if self.db_settings is not None:
+            save_updated_trial(
+                experiment=self.experiment, trial=trial, db_settings=self.db_settings
+            )
+            return True
+        return False
+
+    @retry_on_exception(
+        retries=3,
+        default_return_on_suppression=False,
+        exception_type=retry_exception_type_tuple,
+    )
+    def _save_generation_strategy_to_db_if_possible(
+        self, suppress_all_errors: bool = False
+    ) -> bool:
+        """Saves attached experiment and generation strategy if DB settings are
+        set on this AxClient instance.
+
+        Returns:
+            bool: Whether the experiment was saved.
+        """
+        if self.db_settings is not None:
+            save_generation_strategy(
+                generation_strategy=self.generation_strategy,
+                db_settings=self.db_settings,
+            )
             return True
         return False
 
