@@ -16,7 +16,7 @@ from ax.core.experiment import Experiment
 from ax.core.generator_run import GeneratorRun, GeneratorRunType
 from ax.core.metric import Metric
 from ax.core.multi_type_experiment import MultiTypeExperiment
-from ax.core.objective import Objective, ScalarizedObjective
+from ax.core.objective import MultiObjective, Objective, ScalarizedObjective
 from ax.core.optimization_config import OptimizationConfig
 from ax.core.outcome_constraint import OutcomeConstraint
 from ax.core.parameter import ChoiceParameter, FixedParameter, Parameter, RangeParameter
@@ -288,7 +288,7 @@ class Encoder:
         # name and lower_is_better are stored directly on the metric,
         # so we don't need to include these in the properties blob
         properties = get_object_properties(
-            object=metric, exclude_fields=["name", "lower_is_better"]
+            object=metric, exclude_fields=["name", "lower_is_better", "precomp_config"]
         )
 
         return metric_type, properties
@@ -313,6 +313,8 @@ class Encoder:
 
         if isinstance(objective, ScalarizedObjective):
             return self.scalarized_objective_to_sqa(objective)
+        if isinstance(objective, MultiObjective):
+            return self.multi_objective_to_sqa(objective)
 
         metric = objective.metric
         metric_type, properties = self.get_metric_type_and_properties(metric=metric)
@@ -329,6 +331,59 @@ class Encoder:
             lower_is_better=metric.lower_is_better,
         )
 
+    def multi_objective_to_sqa(self, objective: MultiObjective) -> SQAMetric:
+        """Convert Ax Multi Objective to SQLAlchemy. Returns a parent
+        SQAMetric, whose children are the SQAMetrics corresponding to
+        metrics attribute of MultiObjective. The parent is used as a placeholder
+        for storage purposes."""
+        metrics = objective.metrics
+
+        # pyre-fixme[9]: Expected SQABase type of an attribute;
+        # re-defined to be SQAMetric.
+        metrics_by_name: Dict[
+            str, Tuple[Metric, SQAMetric, Tuple[int, Dict[str, Any]]]
+        ] = {
+            metric.name: (
+                metric,
+                self.config.class_to_sqa_class[Metric],
+                self.get_metric_type_and_properties(metric=metric),
+            )
+            for metric in metrics
+        }
+
+        # Constructing children SQAMetric classes
+        children_metrics = [
+            # pyre-fixme[29]: `SQAMetric` is not a function.
+            metric_class(
+                name=metric.name,
+                metric_type=metrics_type_and_properties[0],
+                intent=MetricIntent.OBJECTIVE,
+                minimize=objective.minimize,
+                properties=metrics_type_and_properties[1],
+                lower_is_better=metric.lower_is_better,
+            )
+            for metric_name, (
+                metric,
+                metric_class,
+                metrics_type_and_properties,
+            ) in metrics_by_name.items()
+        ]
+
+        # Constructing a parent SQAMetric class
+        # pyre-fixme: Expected `Base` for 1st...t `typing.Type[Metric]`.
+        parent_metric: SQAMetric = self.config.class_to_sqa_class[Metric]
+        # pyre-fixme[29]: `SQAMetric` is not a function.
+        parent_metric = parent_metric(
+            name="scalarized_objective",
+            metric_type=METRIC_REGISTRY[Metric],
+            intent=MetricIntent.MULTI_OBJECTIVE,
+            minimize=objective.minimize,
+            lower_is_better=objective.minimize,
+            scalarized_objective_children_metrics=children_metrics,
+        )
+
+        return parent_metric
+
     def scalarized_objective_to_sqa(self, objective: ScalarizedObjective) -> SQAMetric:
         """Convert Ax Scalarized Objective to SQLAlchemy. Returns a parent
         SQAMetric, whose children are the SQAMetrics corresponding to
